=========================================================
Dutch word list
=========================================================
A simple python package that exports a list of almost 10,000 Dutch words ranked by usage.

Usage
=====
::

    import dutch_words
    words = dutch_words.get_ranked()

Thanks
======
Thanks to `Sasha Romijn <https://github.com/mxsasha>`_ for the inspiration and the University of
Leipzig for the `Dutch word list <http://wortschatz.uni-leipzig.de/en/download/>`_.

License
=======
The word list provided by the University of Leipzig and the python code are available under the `CC BY 4.0 <https://creativecommons.org/licenses/by/4.0/>`_ license.
